#!/usr/bin/env python

from setuptools import setup

if __name__ == '__main__':
    setup(
          name = 'fysom',
          version = '1.0.6',
          description = 'pYthOn Finite State Machine',
          long_description = '''Please visit https://github.com/mriehl/fysom for more information.''',
          author = "Mansour Behabadi, Jake Gordon, Maximilien Riehl",
          author_email = "mansour@oxplot.com, jake@codeincomplete.com, maximilien.riehl@gmail.com",
          license = 'MIT',
          url = 'https://github.com/mriehl/fysom',
          scripts = [],
          packages = ['fysom'],
          classifiers = ['Development Status :: 3 - Alpha', 'Programming Language :: Python'],
          
          
          
          
          zip_safe=True
    )
